PackedZipRemoteDataSet
======================

.. currentmodule:: pykeen.datasets.base

.. autoclass:: PackedZipRemoteDataSet
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~PackedZipRemoteDataSet.head_column
      ~PackedZipRemoteDataSet.header
      ~PackedZipRemoteDataSet.relation_column
      ~PackedZipRemoteDataSet.sep
      ~PackedZipRemoteDataSet.tail_column

   .. rubric:: Attributes Documentation

   .. autoattribute:: head_column
   .. autoattribute:: header
   .. autoattribute:: relation_column
   .. autoattribute:: sep
   .. autoattribute:: tail_column
